#!/bin/bash

# URL and file name
URL=$1
FILENAME=`basename $URL`

# Number of parts
PARTS=$SLURM_NTASKS
echo "Downloading in $PARTS parts..."

# Create temporary directory for parts
TEMP_DIR=$(mktemp -d)

# Calculate the range for each part
FILE_SIZE=$(curl -sIk $URL | awk '/Content-Length/ {print $2}' | tr -d '\r')  # Get file size
PART_SIZE=$((FILE_SIZE / PARTS))  # Calculate part size
LAST_PART_SIZE=$((FILE_SIZE - PART_SIZE * (PARTS - 1)))  # Calculate size of the last part

# Download each part concurrently
for ((i = 0; i < PARTS; i++)); do
  start=$((i * PART_SIZE))
  end=$((start + PART_SIZE - 1))

  if [[ $i -eq $((PARTS - 1)) ]]; then
    end=$((start + LAST_PART_SIZE - 1))
  fi

  curl -ks -o "$TEMP_DIR/part$i" --range "$start-$end" "$URL" &
done

# Wait for all downloads to finish
wait

# Merge the parts into a single file
for ((i = 0; i < PARTS; i++)); do
  cat "$TEMP_DIR/part$i" >> "data/$FILENAME"
done

# Clean up temporary directory
rm -rf "$TEMP_DIR"

echo "Download completed!"


