#!/bin/bash

# Check if an argument (number of iterations) is provided
if [ -z "$1" ]; then
  echo "Usage: $0 <number_of_iterations>"
  exit 1
fi

iterations=$1
inside_circle=0

# Loop through the number of iterations
for ((i=0; i<$iterations; i++)); do
  # Generate random points between 0 and 1 for x and y
  x=$(awk -v seed=$RANDOM 'BEGIN{srand(seed); print rand()}')
  y=$(awk -v seed=$RANDOM 'BEGIN{srand(seed); print rand()}')

  # Calculate distance from origin (0, 0)
  distance=$(echo "$x^2 + $y^2" | bc -l 2>/dev/null)

  # If the point lies inside the unit circle, increase count
  if (( $(echo "$distance <= 1" | bc -l 2>/dev/null) )); then
    inside_circle=$((inside_circle + 1))
  fi
done

# Estimate Pi
pi=$(echo "4 * $inside_circle / $iterations" | bc -l 2>/dev/null)

# Output result
echo "niter=$iterations"
echo "count in circle:$inside_circle"
echo "Pi: $pi"
